Test website

This page contains tests around varying images based on screen / device.

## Image srcset

An image should be displayed below at all screen sizes and pixel ratios.

Another image should be displayed below at all screen sizes and pixel ratios.

## Picture sources - with srcset pixel ratio

An image should be displayed below at all screen sizes and pixel ratios.

## Picture sources - with media queries

An image should be displayed below at all screen sizes and pixel ratios.